% Auto-generated chapter 32 for ibnmajah
% Hadiths in this chapter: 107

\hadithdefcmd{ibnmajah}{3550}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ صَلَّى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فِي خَمِيصَةٍ لَهَا أَعْلاَمٌ فَقَالَ ‏ "‏ شَغَلَنِي أَعْلاَمُ هَذِهِ اذْهَبُوا بِهَا إِلَى أَبِي جَهْمٍ وَائْتُونِي بِأَنْبِجَانِيَّتِهِ ‏"‏ ‏.‏\hadithno{3550}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that ‘Aishah said:“The Messenger of Allah (ﷺ) prayed in a Khamisah* that had markings on it. Then he said: ‘These markings distracted me. Take it to Abu Jahm and bring me an Anbijaniyyah.’”}}
\hadithdefcmd{ibnmajah}{3551}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، أَخْبَرَنِي سُلَيْمَانُ بْنُ الْمُغِيرَةِ، عَنْ حُمَيْدِ بْنِ هِلاَلٍ، عَنْ أَبِي بُرْدَةَ، قَالَ دَخَلْتُ عَلَى عَائِشَةَ فَأَخْرَجَتْ لِي إِزَارًا غَلِيظًا مِنَ الَّتِي تُصْنَعُ بِالْيَمَنِ وَكِسَاءً مِنْ هَذِهِ الأَكْسِيَةِ الَّتِي تُدْعَى الْمُلَبَّدَةَ وَأَقْسَمَتْ لِي لَقُبِضَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فِيهِمَا ‏.‏\hadithno{3551}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Burdah said:“I entered upon ‘Aishah and she brought out to me a thick waist wrap of the type made in Yemen, and one of these cloaks that are called Mulabbadah,* and she swore to me that the Messenger of Allah (ﷺ) had passed away in them.”}}
\hadithdefcmd{ibnmajah}{3552}{حَدَّثَنَا أَحْمَدُ بْنُ ثَابِتٍ الْجَحْدَرِيُّ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الأَحْوَصِ بْنِ حَكِيمٍ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ صَلَّى فِي شَمْلَةٍ قَدْ عَقَدَ عَلَيْهَا ‏.‏\hadithno{3552}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Fouad Abd al-Baqi: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Ubadah bin Samit that the Messenger of Allah (ﷺ) prayed in a Shamlah tied with a knot}}
\hadithdefcmd{ibnmajah}{3553}{حَدَّثَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، حَدَّثَنَا ابْنُ وَهْبٍ، حَدَّثَنَا مَالِكٌ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كُنْتُ مَعَ النَّبِيِّ ـ صلى الله عليه وسلم ـ وَعَلَيْهِ رِدَاءٌ نَجْرَانِيٌّ غَلِيظُ الْحَاشِيَةِ ‏.‏\hadithno{3553}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Anas bin Malik said:“I was with the Messenger of Allah (ﷺ) and over him was a Najrani upper wrap with a thick border.”}}
\hadithdefcmd{ibnmajah}{3554}{حَدَّثَنَا عَبْدُ الْقُدُّوسِ بْنُ مُحَمَّدٍ، حَدَّثَنَا بِشْرُ بْنُ عُمَرَ، حَدَّثَنَا ابْنُ لَهِيعَةَ، حَدَّثَنَا أَبُو الأَسْوَدِ، عَنْ عَاصِمِ بْنِ عُمَرَ بْنِ قَتَادَةَ، عَنْ عَلِيِّ بْنِ الْحُسَيْنِ، عَنْ عَائِشَةَ، قَالَتْ مَا رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَسُبُّ أَحَدًا وَلاَ يُطْوَى لَهُ ثَوْبٌ ‏.‏\hadithno{3554}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Aishah said:“I never saw the Messenger of Allah (ﷺ) insulting anyone, and no garment was ever folded up for him.”}}
\hadithdefcmd{ibnmajah}{3555}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، عَنْ أَبِيهِ، عَنْ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيِّ، أَنَّ امْرَأَةً، جَاءَتْ إِلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ بِبُرْدَةٍ - قَالَ وَمَا الْبُرْدَةُ قَالَ الشَّمْلَةُ - قَالَتْ يَا رَسُولَ اللَّهِ إِنِّي نَسَجْتُ هَذِهِ بِيَدِي لأَكْسُوَكَهَا ‏.‏ فَأَخَذَهَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ مُحْتَاجًا إِلَيْهَا فَخَرَجَ عَلَيْنَا فِيهَا وَإِنَّهَا لإِزَارُهُ فَجَاءَ فُلاَنُ بْنُ فُلاَنٍ - رَجُلٌ سَمَّاهُ يَوْمَئِذٍ - فَقَالَ يَا رَسُولَ اللَّهِ مَا أَحْسَنَ هَذِهِ الْبُرْدَةَ اكْسُنِيهَا ‏.‏ قَالَ ‏ "‏ نَعَمْ ‏"‏ ‏.‏ فَلَمَّا دَخَلَ طَوَاهَا وَأَرْسَلَ بِهَا إِلَيْهِ فَقَالَ لَهُ الْقَوْمُ وَاللَّهِ مَا أَحْسَنْتَ كُسِيَهَا النَّبِيُّ ـ صلى الله عليه وسلم ـ مُحْتَاجًا إِلَيْهَا ثُمَّ سَأَلْتَهُ إِيَّاهَا وَقَدْ عَلِمْتَ أَنَّهُ لاَ يَرُدُّ سَائِلاً ‏.‏ فَقَالَ إِنِّي وَاللَّهِ مَا سَأَلْتُهُ إِيَّاهَا لأَلْبَسَهَا وَلَكِنْ سَأَلْتُهُ إِيَّاهَا لِتَكُونَ كَفَنِي ‏.‏ فَقَالَ سَهْلٌ فَكَانَتْ كَفَنَهُ يَوْمَ مَاتَ ‏.‏\hadithno{3555}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Sahl bin Sa’d Sa’idi that a woman came to the Messenger of Allah (ﷺ) with a woven sheet – he said:* “What type of woven sheet?” He said: “A Shamlah.” She said: “O Messenger of Allah, I have woven this with my own hands for you to wear.” The Messenger of Allah (ﷺ) took it, since he needed it. He came out to us wearing it as a lower wrap. So-and-so the son of so-and-so.” – a man whose name he told that day – said: “O Messenger of Allah, how beautiful this sheet is! Let me wear it.” He said: “Yes.” When he went inside he folded it up and sent it to him. The people said to him: “By Allah, you have not done well. The Prophet (ﷺ) wore it because he needed it, then you asked for it, and you knew that he would not refuse anyone who asked him for something.” He said: “By Allah, I did not ask for it so that I could wear it, rather I asked for it so that it could be my shroud.” Sahl said: “And it became his shroud the day he died.”}}
\hadithdefcmd{ibnmajah}{3556}{حَدَّثَنَا يَحْيَى بْنُ عُثْمَانَ بْنِ سَعِيدِ بْنِ كَثِيرِ بْنِ دِينَارٍ الْحِمْصِيُّ، حَدَّثَنَا بَقِيَّةُ بْنُ الْوَلِيدِ، عَنْ يُوسُفَ بْنِ أَبِي كَثِيرٍ، عَنْ نُوحِ بْنِ ذَكْوَانَ، عَنِ الْحَسَنِ، عَنْ أَنَسٍ، قَالَ لَبِسَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ الصُّوفَ وَاحْتَذَى الْمَخْصُوفَ وَلَبِسَ ثَوْبًا خَشِنًا خَشِنًا ‏.‏\hadithno{3556}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Anas said:“The Messenger of Allah (ﷺ) wore wool and sandals, and he wore coarse, rough garments.”}}
\hadithdefcmd{ibnmajah}{3557}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، قَالَ حَدَّثَنَا أَصْبَغُ بْنُ زَيْدٍ، حَدَّثَنَا أَبُو الْعَلاَءِ، عَنْ أَبِي أُمَامَةَ، قَالَ لَبِسَ عُمَرُ بْنُ الْخَطَّابِ ثَوْبًا جَدِيدًا فَقَالَ الْحَمْدُ لِلَّهِ الَّذِي كَسَانِي مَا أُوَارِي بِهِ عَوْرَتِي وَأَتَجَمَّلُ بِهِ فِي حَيَاتِي ثُمَّ قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ مَنْ لَبِسَ ثَوْبًا جَدِيدًا فَقَالَ الْحَمْدُ لِلَّهِ الَّذِي كَسَانِي مَا أُوَارِي بِهِ عَوْرَتِي وَأَتَجَمَّلُ بِهِ فِي حَيَاتِي ‏.‏ ثُمَّ عَمَدَ إِلَى الثَّوْبِ الَّذِي أَخْلَقَ أَوْ أَلْقَى فَتَصَدَّقَ بِهِ كَانَ فِي كَنَفِ اللَّهِ وَفِي حِفْظِ اللَّهِ وَفِي سِتْرِ اللَّهِ حَيًّا وَمَيِّتًا ‏"‏ ‏.‏ قَالَهَا ثَلاَثًا ‏.‏\hadithno{3557}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Umamah said:“Umar bin Khattab put on a new garment and said: Al-hamdu lillahil-ladhi kasani ma uwari bihi ‘awrati, wa atajammalu bihi fi hayati (Praise is to Allah Who has clothed me in something with which I conceal my nakedness and adorn myself in my life). Then he said: ‘I heard the Messenger of Allah (ﷺ) say: “Whoever puts on a new garment and says: Al-hamdu lillahil- ladhi kasani ma uwari bihi ‘awrati, wa atajammalu bihi fi hayati (Praise be to Allah Who has clothed me in something with which I conceal my nakedness and adorn myself in my life), then takes the garment that has worn out, or that he had taken off and gives it in charity, he will be under the shelter, protection and care of Allah, whether he lives or dies.’ He said this three times.”}}
\hadithdefcmd{ibnmajah}{3558}{حَدَّثَنَا الْحُسَيْنُ بْنُ مَهْدِيٍّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ رَأَى عَلَى عُمَرَ قَمِيصًا أَبْيَضَ فَقَالَ ‏"‏ ثَوْبُكَ هَذَا غَسِيلٌ أَمْ جَدِيدٌ ‏"‏ ‏.‏ قَالَ لاَ بَلْ غَسِيلٌ ‏.‏ قَالَ ‏"‏ الْبَسْ جَدِيدًا وَعِشْ حَمِيدًا وَمُتْ شَهِيدًا ‏"‏ ‏.‏\hadithno{3558}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn `Umar that the Messenger of Allah (ﷺ) saw `Umar wearing a white shirt and he said:“Is this garment of yours washed or a new one?” He said: “Rather it has been washed.” He said: “Ilbas jadida, wa `ish hamida, wa mut shahida (May you wear new clothes, live a good life and die as martyr).”}}
\hadithdefcmd{ibnmajah}{3559}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عَطَاءِ بْنِ يَزِيدَ اللَّيْثِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ نَهَى عَنْ لِبْسَتَيْنِ فَأَمَّا اللِّبْسَتَانِ فَاشْتِمَالُ الصَّمَّاءِ وَالاِحْتِبَاءُ فِي الثَّوْبِ الْوَاحِدِ لَيْسَ عَلَى فَرْجِهِ مِنْهُ شَىْءٌ ‏.‏\hadithno{3559}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Sa’eed Al-Khudri that the Prophet (ﷺ) forbade two kinds of dress. Those two types of dress are Ishtimalus- Samma’* and Ihtiba’ in a single garment, with no part of it upon his private part}}
\hadithdefcmd{ibnmajah}{3560}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، وَأَبُو أُسَامَةَ عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ خُبَيْبِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ حَفْصِ بْنِ عَاصِمٍ، عَنْ أَبِي هُرَيْرَةَ، ‏.‏ أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ نَهَى عَنْ لِبْسَتَيْنِ عَنِ اشْتِمَالِ الصَّمَّاءِ وَعَنِ الاِحْتِبَاءِ فِي الثَّوْبِ الْوَاحِدِ يُفْضِي بِفَرْجِهِ إِلَى السَّمَاءِ ‏.‏\hadithno{3560}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) forbade two kinds of dress:Ishtimalus-Samma’ and Ihtiba’, exposing one’s private part to the sky}}
\hadithdefcmd{ibnmajah}{3561}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، وَأَبُو أُسَامَةَ عَنْ سَعْدِ بْنِ سَعِيدٍ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، قَالَتْ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنْ لِبْسَتَيْنِ اشْتِمَالِ الصَّمَّاءِ وَالاِحْتِبَاءِ فِي ثَوْبٍ وَاحِدٍ وَأَنْتَ مُفْضٍ فَرْجَكَ إِلَى السَّمَاءِ ‏.‏\hadithno{3561}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that ‘Aishah said:“The Messenger of Allah (ﷺ) forbade two kinds of dress: Ishtimalus-Samma’ and Ihtiba’ in one garment, when you are exposing your private part to the sky.”}}
\hadithdefcmd{ibnmajah}{3562}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا الْحَسَنُ بْنُ مُوسَى، عَنْ شَيْبَانَ، عَنْ قَتَادَةَ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِيهِ، قَالَ قَالَ لِي يَا بُنَىَّ لَوْ شَهِدْتَنَا وَنَحْنُ مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ إِذَا أَصَابَتْنَا السَّمَاءُ لَحَسِبْتَ أَنَّ رِيحَنَا رِيحُ الضَّأْنِ ‏.‏\hadithno{3562}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Burdah that his father said to him:“O my son, if only you could have seen us when we were with the Messenger of Allah (ﷺ), when rain fell on us; you would have thought that we smelled like sheep.”}}
\hadithdefcmd{ibnmajah}{3563}{حَدَّثَنَا مُحَمَّدُ بْنُ عُثْمَانَ بْنِ كَرَامَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا الأَحْوَصُ بْنُ حَكِيمٍ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، قَالَ خَرَجَ عَلَيْنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ذَاتَ يَوْمٍ وَعَلَيْهِ جُبَّةٌ رُومِيَّةٌ مِنْ صُوفٍ ضَيِّقَةُ الْكُمَّيْنِ فَصَلَّى بِنَا فِيهَا لَيْسَ عَلَيْهِ شَىْءٌ غَيْرُهَا ‏.‏\hadithno{3563}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Ubadah bin Samit said:“The Messenger of Allah (ﷺ) came out to us one day, wearing a Roman cloak of wool with narrow sleeves. He led us in prayer wearing that, and nothing else.”}}
\hadithdefcmd{ibnmajah}{3564}{حَدَّثَنَا الْعَبَّاسُ بْنُ الْوَلِيدِ الدِّمَشْقِيُّ، وَأَحْمَدُ بْنُ الأَزْهَرِ، قَالاَ حَدَّثَنَا مَرْوَانُ بْنُ مُحَمَّدٍ، حَدَّثَنَا يَزِيدُ بْنُ السِّمْطِ، حَدَّثَنِي الْوَضِينُ بْنُ عَطَاءٍ، عَنْ مَحْفُوظِ بْنِ عَلْقَمَةَ، عَنْ سَلْمَانَ الْفَارِسِيِّ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ تَوَضَّأَ فَقَلَبَ جُبَّةَ صُوفٍ كَانَتْ عَلَيْهِ فَمَسَحَ بِهَا وَجْهَهُ ‏.‏\hadithno{3564}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Salman Farisi that the Messenger of Allah (ﷺ) performed ablution, then he turned his woolen cloak that he was wearing inside out and wiped his face with it}}
\hadithdefcmd{ibnmajah}{3565}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا مُوسَى بْنُ الْفَضْلِ، عَنْ شُعْبَةَ، عَنْ هِشَامِ بْنِ زَيْدٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَسِمُ غَنَمًا فِي آذَانِهَا وَرَأَيْتُهُ مُتَّزِرًا بِكِسَاءٍ ‏.‏\hadithno{3565}\hadithgrade{Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Anas bin Malik said:“I saw the Messenger of Allah (ﷺ) marking sheep on their ears, and I saw him wearing a cloak around his wrist.”}}
\hadithdefcmd{ibnmajah}{3566}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ رَجَاءٍ الْمَكِّيُّ، عَنِ ابْنِ خُثَيْمٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ خَيْرُ ثِيَابِكُمُ الْبَيَاضُ فَالْبَسُوهَا وَكَفِّنُوا فِيهَا مَوْتَاكُمْ ‏"‏ ‏.‏\hadithno{3566}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn ‘Abbas that the Messenger of Allah (ﷺ) said:“The best of your garments are the white ones, so wear them and shroud your dead in them.”}}
\hadithdefcmd{ibnmajah}{3567}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ مَيْمُونِ بْنِ أَبِي شَبِيبٍ، عَنْ سَمُرَةَ بْنِ جُنْدَبٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الْبَسُوا ثِيَابَ الْبَيَاضِ فَإِنَّهَا أَطْهَرُ وَأَطْيَبُ ‏"‏ ‏.‏\hadithno{3567}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Samurah bin Jundab that the Messenger of Allah (ﷺ) said:“Wear white garments, for they are purer and better.”}}
\hadithdefcmd{ibnmajah}{3568}{حَدَّثَنَا مُحَمَّدُ بْنُ حَسَّانَ الأَزْرَقُ، حَدَّثَنَا عَبْدُ الْمَجِيدِ بْنُ أَبِي رَوَّادٍ، حَدَّثَنَا مَرْوَانُ بْنُ سَالِمٍ، عَنْ صَفْوَانَ بْنِ عَمْرٍو، عَنْ شُرَيْحِ بْنِ عُبَيْدٍ الْحَضْرَمِيِّ، عَنْ أَبِي الدَّرْدَاءِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ أَحْسَنَ مَا زُرْتُمُ اللَّهَ بِهِ فِي قُبُورِكُمْ وَمَسَاجِدِكُمُ الْبَيَاضُ ‏"‏ ‏.‏\hadithno{3568}\hadithgrade{Al-Albani: Mawdu; Muhammad Fouad Abd al-Baqi: Mawdu; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Darda’ that the Messenger of Allah (ﷺ) said:“The best of that in which you visit Allah in your graves and your mosque is white (garments).”}}
\hadithdefcmd{ibnmajah}{3569}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، ح وَحَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، جَمِيعًا عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِنَّ الَّذِي يَجُرُّ ثَوْبَهُ مِنَ الْخُيَلاَءِ لاَ يَنْظُرُ اللَّهُ إِلَيْهِ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{3569}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn ‘Umar that the Messenger of Allah (ﷺ) said:“Whoever lets his garment drag out of pride, Allah will not look at him on the Day of Resurrection.”}}
\hadithdefcmd{ibnmajah}{3570}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ عَطِيَّةَ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ جَرَّ إِزَارَهُ مِنَ الْخُيَلاَءِ لَمْ يَنْظُرِ اللَّهُ إِلَيْهِ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ قَالَ فَلَقِيتُ ابْنَ عُمَرَ بِالْبَلاَطِ فَذَكَرْتُ لَهُ حَدِيثَ أَبِي سَعِيدٍ عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ فَقَالَ وَأَشَارَ إِلَى أُذُنَيْهِ سَمِعَتْهُ أُذُنَاىَ وَوَعَاهُ قَلْبِي ‏.‏\hadithno{3570}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from ‘Atiyyah, that Abu Sa’eed said:“The Messenger of Allah (ﷺ) said: ‘Whoever lets his lower wrap drag out of pride, Allah will not look at him on the Day of Resurrection.” He ( ‘Atiyyah) said "I met Ibn 'Umar in Al-Balaat so I mentioned Abu Sa'eed's hadith from the Prophet (ﷺ). So he said and pointed to his ears 'My two ears heard it, and my heart preserved it}}
\hadithdefcmd{ibnmajah}{3571}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ مَرَّ بِأَبِي هُرَيْرَةَ فَتًى مِنْ قُرَيْشٍ يَجُرُّ سَبَلَهُ فَقَالَ يَا ابْنَ أَخِي إِنِّي سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ مَنْ جَرَّ ثَوْبَهُ مِنَ الْخُيَلاَءِ لَمْ يَنْظُرِ اللَّهُ له يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{3571}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that a young man of Quriash passed by Abu Hurairah with his cloak dragging. He said:“O my nephew! I heard the Messenger of Allah (ﷺ) saying ‘Whoever let his garment drag out of pride, Allah will not look at him on the Day of Resurrection.’”}}
\hadithdefcmd{ibnmajah}{3572}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنْ مُسْلِمِ بْنِ نُذَيْرٍ، عَنْ حُذَيْفَةَ، قَالَ أَخَذَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ بِأَسْفَلِ عَضَلَةِ سَاقِي أَوْ سَاقِهِ فَقَالَ ‏ "‏ هَذَا مَوْضِعُ الإِزَارِ فَإِنْ أَبَيْتَ ‏.‏ فَأَسْفَلَ فَإِنْ أَبَيْتَ فَأَسْفَلَ فَإِنْ أَبَيْتَ فَلاَ حَقَّ لِلإِزَارِ فِي الْكَعْبَيْنِ ‏"‏ ‏.‏ حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، حَدَّثَنِي أَبُو إِسْحَاقَ، عَنْ مُسْلِمِ بْنِ نُذَيْرٍ، عَنْ حُذَيْفَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ مِثْلَهُ ‏.‏\hadithno{3572}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Hudhaifah said:“The Messenger of Allah (ﷺ) took hold of the lower part of my calf or his calf and said: ‘This is where the lower wrap should come to. If you insist, then lower, and if you insist, then lower, but the lower wrap has no right to (come to) the ankle.’”}}
\hadithdefcmd{ibnmajah}{3573}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، قَالَ قُلْتُ لأَبِي سَعِيدٍ هَلْ سَمِعْتَ مِنْ، رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ شَيْئًا فِي الإِزَارِ قَالَ نَعَمْ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏"‏ إِزْرَةُ الْمُؤْمِنِ إِلَى أَنْصَافِ سَاقَيْهِ لاَ جُنَاحَ عَلَيْهِ مَا بَيْنَهُ وَبَيْنَ الْكَعْبَيْنِ وَمَا أَسْفَلَ مِنَ الْكَعْبَيْنِ فِي النَّارِ ‏"‏ ‏.‏ يَقُولُ ثَلاَثًا ‏"‏ لاَ يَنْظُرُ اللَّهُ إِلَى مَنْ جَرَّ إِزَارَهُ بَطَرًا ‏"‏ ‏.‏\hadithno{3573}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from ‘Ala bin ‘Abdur-Rahman that his father said:“I said to Abu Sa’eed: ‘Did you hear anything from the Messenger of Allah (ﷺ) concerning the lower wrap?’ He said: ‘Yes. I heard the Messenger of Allah (ﷺ) say: ‘The lower wrap of the believer should come to mid-calf, but there is no sin on him if it comes between that point and the ankle. But whatever is lower than the ankle is in the Fire.’ And he said three times: ‘Allah will not look at the one who lets his lower wrap drag out of vanity.’”}}
\hadithdefcmd{ibnmajah}{3574}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا شَرِيكٌ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ حُصَيْنِ بْنِ قَبِيصَةَ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ يَا سُفْيَانَ بْنَ سَهْلٍ لاَ تُسْبِلْ فَإِنَّ اللَّهَ لاَ يُحِبُّ الْمُسْبِلِينَ ‏"‏ ‏.‏\hadithno{3574}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Mughirah bin Shu’bah that the Messenger of Allah (ﷺ) said:“O Sufyan bin Sahl, do not let your garment hang, for Allah does not like those who let their garments hang below the ankles.’”}}
\hadithdefcmd{ibnmajah}{3575}{حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، حَدَّثَنَا أَبُو تُمَيْلَةَ، عَنْ عَبْدِ الْمُؤْمِنِ بْنِ خَالِدٍ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ أُمِّهِ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ لَمْ يَكُنْ ثَوْبٌ أَحَبَّ إِلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ مِنَ الْقَمِيصِ ‏.‏\hadithno{3575}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Umm Salamah said:There was no garment more beloved to the Messenger of Allah (ﷺ) than the shirt.”}}
\hadithdefcmd{ibnmajah}{3576}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا الْحُسَيْنُ بْنُ عَلِيٍّ، عَنِ ابْنِ أَبِي رَوَّادٍ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ الإِسْبَالُ فِي الإِزَارِ وَالْقَمِيصِ وَالْعِمَامَةِ مَنْ جَرَّ شَيْئًا خُيَلاَءَ لَمْ يَنْظُرِ اللَّهُ إِلَيْهِ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ قَالَ أَبُو بَكْرٍ مَا أَغْرَبَهُ ‏.‏\hadithno{3576}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Salim, from his father, that the Prophet (ﷺ) said:“Hanging down may apply to the waist wrap, shirt or turban. Whoever lets any of these drag out of pride, Allah will not look at him on the Day of Resurrection.”}}
\hadithdefcmd{ibnmajah}{3577}{حَدَّثَنَا أَحْمَدُ بْنُ عُثْمَانَ بْنِ حَكِيمٍ الأَوْدِيُّ، حَدَّثَنَا أَبُو غَسَّانَ، قَالَ حَدَّثَنَا حَسَنُ بْنُ صَالِحٍ، ح وَحَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا أَبِي، عَنِ الْحَسَنِ بْنِ صَالِحٍ، عَنْ مُسْلِمٍ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَلْبَسُ قَمِيصًا قَصِيرَ الْيَدَيْنِ وَالطُّولِ ‏.‏\hadithno{3577}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Abbas said:“The Messenger of Allah (ﷺ) used to wear a shirt that was short in the sleeves and length.”}}
\hadithdefcmd{ibnmajah}{3578}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا ابْنُ دُكَيْنٍ، عَنْ زُهَيْرٍ، عَنْ عُرْوَةَ بْنِ عَبْدِ اللَّهِ بْنِ قُشَيْرٍ، حَدَّثَنِي مُعَاوِيَةُ بْنُ قُرَّةَ، عَنْ أَبِيهِ، قَالَ أَتَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ فَبَايَعْتُهُ وَإِنَّ زِرَّ قَمِيصِهِ لَمُطْلَقٌ ‏.‏ قَالَ عُرْوَةُ فَمَا رَأَيْتُ مُعَاوِيَةَ وَلاَ ابْنَهُ فِي شِتَاءٍ وَلاَ صَيْفٍ إِلاَّ مُطْلَقَةً أَزْرَارُهُمَا ‏.‏\hadithno{3578}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Mu’awiyah bin Qurrah narrated that his father said:“I came to the Messenger of Allah (ﷺ) and gave him my pledge, and the buttons of his shirt were undone.”}}
\hadithdefcmd{ibnmajah}{3579}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى، وَعَبْدُ الرَّحْمَنِ، قَالُوا حَدَّثَنَا سُفْيَانُ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ سُوَيْدِ بْنِ قَيْسٍ، قَالَ أَتَانَا النَّبِيُّ ـ صلى الله عليه وسلم ـ فَسَاوَمَنَا سَرَاوِيلَ ‏.‏\hadithno{3579}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Suwaid bin Qais said:“The Prophet (ﷺ) came to us and haggled with us over the price of trousers.”}}
\hadithdefcmd{ibnmajah}{3580}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا الْمُعْتَمِرُ بْنُ سُلَيْمَانَ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ سُئِلَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ كَمْ تَجُرُّ الْمَرْأَةُ مِنْ ذَيْلِهَا قَالَ ‏"‏ شِبْرًا ‏"‏ ‏.‏ قُلْتُ إِذًا يَنْكَشِفَ عَنْهَا ‏.‏ قَالَ ذِرَاعٌ لاَ تَزِيدُ عَلَيْهِ ‏"‏ ‏.‏\hadithno{3580}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Umm Salamah said:“The Messenger of Allah (ﷺ) was asked about how long a woman’s hem should hang down. He said: ‘A hand span.’ I said: ‘But then (her legs and feet) will be uncovered.’ He said: ‘Then a forearm’s length, but no more than that.’”}}
\hadithdefcmd{ibnmajah}{3581}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ سُفْيَانَ، عَنْ زَيْدٍ الْعَمِّيِّ، عَنْ أَبِي الصِّدِّيقِ النَّاجِيِّ، عَنِ ابْنِ عُمَرَ، أَنَّ أَزْوَاجَ النَّبِيِّ، ـ صلى الله عليه وسلم ـ رُخِّصَ لَهُنَّ فِي الذَّيْلِ ذِرَاعًا فَكُنَّ يَأْتِيَنَّا فَنَذْرَعُ لَهُنَّ بِالْقَصَبِ ذِرَاعًا ‏.‏\hadithno{3581}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn ‘Umar:“The wives of the Prophet (ﷺ) were allowed to let their hems hang down, so they used to come to us and we would measure one forearms length for them with a reed.”}}
\hadithdefcmd{ibnmajah}{3582}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ أَبِي الْمُهَزِّمِ، عَنْ أَبِي هُرَيْرَةَ، ‏.‏ أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ لِفَاطِمَةَ أَوْ لأُمِّ سَلَمَةَ ‏ "‏ ذَيْلُكِ ذِرَاعٌ ‏"‏ ‏.‏\hadithno{3582}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said to Fatimah, or to Umm Salamah:“Let your hem down one forearm’s length.”}}
\hadithdefcmd{ibnmajah}{3583}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا حَبِيبٌ الْمُعَلِّمُ، عَنْ أَبِي الْمُهَزِّمِ، عَنْ أَبِي هُرَيْرَةَ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ فِي ذُيُولِ النِّسَاءِ ‏"‏ شِبْرًا ‏"‏ ‏.‏ فَقَالَتْ عَائِشَةُ إِذًا تَخْرُجَ سُوقُهُنَّ ‏.‏ قَالَ ‏"‏ فَذِرَاعٌ ‏"‏ ‏.‏\hadithno{3583}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Aishah that the Prophet (ﷺ) said, concerning how long a woman’s hem should hang down:“A hand span.” ‘Aishah said: “This may show her calves.” He said: “Then a forearm’s length.”}}
\hadithdefcmd{ibnmajah}{3584}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ مُسَاوِرٍ الْوَرَّاقِ، عَنْ جَعْفَرِ بْنِ عَمْرِو بْنِ حُرَيْثٍ، عَنْ أَبِيهِ، قَالَ رَأَيْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ يَخْطُبُ عَلَى الْمِنْبَرِ وَعَلَيْهِ عِمَامَةٌ سَوْدَاءُ ‏.‏\hadithno{3584}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi}\hadithtrans{It was narrated from Ja’far bin ‘Amr bin Huraith that his father said:“I saw the Prophet (ﷺ) delivering a sermon on the pulpit, wearing a black turban.”}}
\hadithdefcmd{ibnmajah}{3585}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ دَخَلَ مَكَّةَ وَعَلَيْهِ عِمَامَةٌ سَوْدَاءُ ‏.‏\hadithno{3585}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih}\hadithtrans{It was narrated from Jabir that the Prophet (ﷺ) entered Makkah wearing a black turban}}
\hadithdefcmd{ibnmajah}{3586}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عُبَيْدُ اللَّهِ، أَنْبَأَنَا مُوسَى بْنُ عُبَيْدَةَ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ دَخَلَ يَوْمَ فَتْحِ مَكَّةَ وَعَلَيْهِ عِمَامَةٌ سَوْدَاءُ ‏.‏\hadithno{3586}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn ‘Umar that the Prophet (ﷺ) entered (Makkah), on the Day of the Conquest of Makkah, wearing a black turban}}
\hadithdefcmd{ibnmajah}{3587}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ مُسَاوِرٍ، حَدَّثَنِي جَعْفَرُ بْنُ عَمْرِو بْنِ حُرَيْثٍ، عَنْ أَبِيهِ، قَالَ كَأَنِّي أَنْظُرُ إِلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ وَعَلَيْهِ عِمَامَةٌ سَوْدَاءُ قَدْ أَرْخَى طَرَفَيْهَا بَيْنَ كَتِفَيْهِ ‏.‏\hadithno{3587}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi}\hadithtrans{Ja’far bin ‘Amr bin Huraith narrated that his father said:“It is as if I can see the Messenger of Allah (ﷺ), wearing a black turban, with the ends hanging down his shoulders.”}}
\hadithdefcmd{ibnmajah}{3588}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ لَبِسَ الْحَرِيرَ فِي الدُّنْيَا لَمْ يَلْبَسْهُ فِي الآخِرَةِ ‏"‏ ‏.‏\hadithno{3588}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah (ﷺ) said:“Whoever wears silk in this world will not wear it in the Hereafter.”}}
\hadithdefcmd{ibnmajah}{3589}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنِ الشَّيْبَانِيِّ، عَنْ أَشْعَثَ بْنِ أَبِي الشَّعْثَاءِ، عَنْ مُعَاوِيَةَ بْنِ سُوَيْدٍ، عَنِ الْبَرَاءِ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنِ الدِّيبَاجِ وَالْحَرِيرِ وَالإِسْتَبْرَقِ ‏.‏\hadithno{3589}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Bara’ bin ‘Azib said:“The Messenger of Allah (ﷺ) forbade brocade, silk, and embroidered brocade.”}}
\hadithdefcmd{ibnmajah}{3590}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ شُعْبَةَ، عَنِ الْحَكَمِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ حُذَيْفَةَ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنْ لُبْسِ الْحَرِيرِ وَالذَّهَبِ وَقَالَ ‏ "‏ هُوَ لَهُمْ فِي الدُّنْيَا وَلَنَا فِي الآخِرَةِ ‏"‏ ‏.‏\hadithno{3590}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Hudhaifah said:“The Messenger of Allah (ﷺ) forbade wearing silk and gold. He said: ‘They are for them in this world and for us in the Hereafter.’”}}
\hadithdefcmd{ibnmajah}{3591}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الرَّحِيمِ بْنُ سُلَيْمَانَ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، أَخْبَرَهُ أَنَّ عُمَرَ بْنَ الْخَطَّابِ رَأَى حُلَّةً سِيَرَاءَ مِنْ حَرِيرٍ فَقَالَ يَا رَسُولَ اللَّهِ لَوِ ابْتَعْتَ هَذِهِ الْحُلَّةَ لِلْوَفْدِ وَلِيَوْمِ الْجُمُعَةِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّمَا يَلْبَسُ هَذَا مَنْ لاَ خَلاَقَ لَهُ فِي الآخِرَةِ ‏"‏ ‏.‏\hadithno{3591}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from ‘Abdullah bin ‘Umar that ‘Umar bin Khattab saw a silken two piece suit (being offered for sale). He said:“O Messenger of Allah, why don’t you buy this two piece suit (to wear for meeting) the delegations, and on Fridays?” The Messenger of Allah (ﷺ) said: “This is only worn by one who has no share in the Hereafter.”}}
\hadithdefcmd{ibnmajah}{3592}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، ‏.‏ أَنَّ أَنَسَ بْنَ مَالِكٍ، نَبَّأَهُمْ أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ رَخَّصَ لِلزُّبَيْرِ بْنِ الْعَوَّامِ وَلِعَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ فِي قَمِيصَيْنِ مِنْ حَرِيرٍ مِنْ وَجَعٍ كَانَ بِهِمَا حِكَّةٍ ‏.‏\hadithno{3592}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah (ﷺ) granted a concession to Zubair bin ‘Awwam and ‘Abdur-Rahman bin ‘Auf, allowing them to wear silk shirts, because of a rash they were suffering from}}
\hadithdefcmd{ibnmajah}{3593}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنْ عَاصِمٍ، عَنْ أَبِي عُثْمَانَ، عَنْ عُمَرَ، أَنَّهُ كَانَ يَنْهَى عَنِ الْحَرِيرِ، وَالدِّيبَاجِ، إِلاَّ مَا كَانَ هَكَذَا ثُمَّ أَشَارَ بِإِصْبَعِهِ ثُمَّ الثَّانِيَةِ ثُمَّ الثَّالِثَةِ ثُمَّ الرَّابِعَةِ فَقَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَنْهَانَا عَنْهُ ‏.‏\hadithno{3593}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from ‘Umar that he used to forbid silk and brocade, except for what was like this:Then he gestured with his finger, then a second, and a third, and a fourth (i.e., the width of four fingers), and he said: “The Messenger of Allah (ﷺ) used to forbid it.”}}
\hadithdefcmd{ibnmajah}{3594}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ مُغِيرَةَ بْنِ زِيَادٍ، عَنْ أَبِي عُمَرَ، مَوْلَى أَسْمَاءَ قَالَ رَأَيْتُ ابْنَ عُمَرَ اشْتَرَى عِمَامَةً لَهَا عَلَمٌ فَدَعَا بِالْجَلَمَيْنِ فَقَصَّهُ فَدَخَلْتُ عَلَى أَسْمَاءَ فَذَكَرْتُ ذَلِكَ لَهَا فَقَالَتْ بُؤْسًا لِعَبْدِ اللَّهِ يَا جَارِيَةُ هَاتِي جُبَّةَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏ فَجَاءَتْ بِجُبَّةٍ مَكْفُوفَةِ الْكُمَّيْنِ وَالْجَيْبِ وَالْفَرْجَيْنِ بِالدِّيبَاجِ ‏.‏\hadithno{3594}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu ‘Umar, the freed slave of Asma’, said:“I saw Ibn ‘Umar buying a turban that had some markings, then he called for a pair of scissors and cut that off. I entered upon Asma’ and mentioned that to her, and she said: ‘May ‘Abdullah perish, O girl! Give me the garment of the Messenger of Allah (ﷺ).’ A garment was brought that was hemmed with brocade on the sleeves, necklines and openings (at the front and back).”}}
\hadithdefcmd{ibnmajah}{3595}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا عَبْدُ الرَّحِيمِ بْنُ سُلَيْمَانَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ عَبْدِ الْعَزِيزِ بْنِ أَبِي الصَّعْبَةِ، عَنْ أَبِي الأَفْلَحِ الْهَمْدَانِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ زُرَيْرٍ الْغَافِقِيِّ، سَمِعْتُهُ يَقُولُ سَمِعْتُ عَلِيَّ بْنَ أَبِي طَالِبٍ، يَقُولُ أَخَذَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ حَرِيرًا بِشِمَالِهِ وَذَهَبًا بِيَمِينِهِ ثُمَّ رَفَعَ بِهِمَا يَدَيْهِ فَقَالَ ‏ "‏ إِنَّ هَذَيْنِ حَرَامٌ عَلَى ذُكُورِ أُمَّتِي حِلٌّ لإِنَاثِهِمْ ‏"‏ ‏.‏\hadithno{3595}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{‘Ali bin Abu Talib said:“The Messenger of Allah (ﷺ) took hold of some silk in his left hand and some gold in his right, then he raised his hands and said: ‘These two are forbidden for the males of my nation, and permitted to the females.’”}}
\hadithdefcmd{ibnmajah}{3596}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الرَّحِيمِ بْنُ سُلَيْمَانَ، عَنْ يَزِيدَ بْنِ أَبِي زِيَادٍ، عَنْ أَبِي فَاخِتَةَ، حَدَّثَنِي هُبَيْرَةُ بْنُ يَرِيمَ، عَنْ عَلِيٍّ، أَنَّهُ أُهْدِيَ لِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ حُلَّةٌ مَكْفُوفَةٌ بِحَرِيرٍ إِمَّا سَدَاؤُهَا وَإِمَّا لُحْمَتُهَا فَأَرْسَلَ بِهَا إِلَىَّ فَأَتَيْتُهُ فَقُلْتُ يَا رَسُولَ اللَّهِ مَا أَصْنَعُ بِهَا أَلْبَسُهَا قَالَ ‏ "‏ لاَ وَلَكِنِ اجْعَلْهَا خُمُرًا بَيْنَ الْفَوَاطِمِ ‏"‏ ‏.‏\hadithno{3596}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from ‘Ali that a two-piece suit hemmed with silk, either on the wrap or the weft,* was given to the Messenger of Allah (ﷺ), and he sent them to me (‘Ali). I came to him and said:“O Messenger of Allah, what should I do with these? Shall I wear them?” He said: “No, rather make them into head-cloths and give them to the Fatimahs.”}}
\hadithdefcmd{ibnmajah}{3597}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا عَبْدُ الرَّحِيمِ بْنُ سُلَيْمَانَ، عَنِ الإِفْرِيقِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ رَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ خَرَجَ عَلَيْنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَفِي إِحْدَى يَدَيْهِ ثَوْبٌ مِنْ حَرِيرٍ وَفِي الأُخْرَى ذَهَبٌ فَقَالَ ‏ "‏ إِنَّ هَذَيْنِ مُحَرَّمٌ عَلَى ذُكُورِ أُمَّتِي حِلٌّ لإِنَاثِهِمْ ‏"‏ ‏.‏\hadithno{3597}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that ‘Abdullah bin ‘Umar said:“The Messenger of Allah (ﷺ) came out to us, and in one of his hands was a garment of silk and in the other was some gold. He said: ‘These are forbidden to the males of my nation and permitted to the females.’”}}
\hadithdefcmd{ibnmajah}{3598}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ أَنَسٍ، قَالَ رَأَيْتُ عَلَى زَيْنَبَ بِنْتِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَمِيصَ حَرِيرٍ سِيَرَاءَ ‏.‏\hadithno{3598}\hadithgrade{Al-Albani: Shadh; Muhammad Fouad Abd al-Baqi: Shadh; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Anas said:“I saw Zainab the daughter of the Messenger of Allah (ﷺ) wearing a shirt of Siyara’ silk}}
\hadithdefcmd{ibnmajah}{3599}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، عَنْ شَرِيكِ بْنِ عَبْدِ اللَّهِ الْقَاضِي، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ، قَالَ مَا رَأَيْتُ أَجْمَلَ مِنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ مُتَرَجِّلاً فِي حُلَّةٍ حَمْرَاءَ ‏.‏\hadithno{3599}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Bara’ said:“I never saw anyone more handsome then the Messenger of Allah (ﷺ), with his hair combed, wearing a red two-piece suit.”}}
\hadithdefcmd{ibnmajah}{3600}{حَدَّثَنَا أَبُو عَامِرٍ عَبْدُ اللَّهِ بْنُ عَامِرِ بْنِ بَرَّادِ بْنِ يُوسُفَ بْنِ أَبِي بُرْدَةَ بْنِ أَبِي مُوسَى الأَشْعَرِيِّ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، حَدَّثَنَا حُسَيْنُ بْنُ وَاقِدٍ، قَاضِي مَرْوَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ بُرَيْدَةَ، أَنَّ أَبَاهُ، حَدَّثَهُ قَالَ رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَخْطُبُ فَأَقْبَلَ حَسَنٌ وَحُسَيْنٌ عَلَيْهِمَا قَمِيصَانِ أَحْمَرَانِ يَعْثُرَانِ وَيَقُومَانِ فَنَزَلَ النَّبِيُّ ـ صلى الله عليه وسلم ـ فَأَخَذَهُمَا فَوَضَعَهُمَا فِي حِجْرِهِ فَقَالَ ‏"‏ صَدَقَ اللَّهُ وَرَسُولُهُ ‏\{إِنَّمَا أَمْوَالُكُمْ وَأَوْلاَدُكُمْ فِتْنَةٌ\}‏ رَأَيْتُ هَذَيْنِ فَلَمْ أَصْبِرْ ‏"‏ ‏.‏ ثُمَّ أَخَذَ فِي خُطْبَتِهِ ‏.‏\hadithno{3600}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{‘Abdullah bin Buraidah narrated that his father told him:I saw the Messenger of Allah (ﷺ) delivering a sermon, and Hasan and Husain came forward, wearing red shirts, stumbling and getting up again. The Prophet (ﷺ) stepped down, picked them up and put them in his lap. Then he said: “Allah and His Messenger have spoken the truth. ‘Your wealth and your children are only a trial.’ [64:15] I saw these two and I could not be patient. Then he resumed his sermon.”}}
\hadithdefcmd{ibnmajah}{3601}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ يَزِيدَ بْنِ أَبِي زِيَادٍ، عَنِ الْحَسَنِ بْنِ سُهَيْلٍ، عَنِ ابْنِ عُمَرَ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنِ الْمُفَدَّمِ ‏.‏ قَالَ يَزِيدُ قُلْتُ لِلْحَسَنِ مَا الْمُفَدَّمُ قَالَ الْمُشْبَعُ بِالْعُصْفُرِ ‏.‏\hadithno{3601}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn ‘Umar said:“The Messenger of Allah (ﷺ) forbade Al-Mufaddam.”}}
\hadithdefcmd{ibnmajah}{3602}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، عَنْ عَبْدِ اللَّهِ بْنِ حُنَيْنٍ، قَالَ سَمِعْتُ عَلِيًّا، يَقُولُ نَهَانِي رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ - وَلاَ أَقُولُ نَهَاكُمْ - عَنْ لُبْسِ الْمُعَصْفَرِ ‏.‏\hadithno{3602}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that ‘Abdullah bin Hunain said:“I heard ‘Ali say: ‘The Messenger of Allah (ﷺ) forbade me – and I do not say that he forbade you – from wearing clothes dyed with safflower.’”}}
\hadithdefcmd{ibnmajah}{3603}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، عَنِ هِشَامِ بْنِ الْغَازِ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ أَقْبَلْنَا مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ مِنْ ثَنِيَّةِ أَذَاخِرَ فَالْتَفَتَ إِلَىَّ وَعَلَىَّ رَيْطَةٌ مُضَرَّجَةٌ بِالْعُصْفُرِ فَقَالَ ‏"‏ مَا هَذِهِ ‏"‏ ‏.‏ فَعَرَفْتُ مَا كَرِهَ فَأَتَيْتُ أَهْلِي وَهُمْ يَسْجُرُونَ تَنُّورَهُمْ فَقَذَفْتُهَا فِيهِ ثُمَّ أَتَيْتُهُ مِنَ الْغَدِ فَقَالَ ‏"‏ يَا عَبْدَ اللَّهِ مَا فَعَلَتِ الرَّيْطَةُ ‏"‏ ‏.‏ فَأَخْبَرْتُهُ فَقَالَ ‏"‏ أَلاَ كَسَوْتَهَا بَعْضَ أَهْلِكَ فَإِنَّهُ لاَ بَأْسَ بِذَلِكَ لِلنِّسَاءِ ‏"‏ ‏.‏\hadithno{3603}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from ‘Amr bin Shu’aib, from his father, that his grandfather said:“We came with the Messenger of Allah (ﷺ) was Thaniyyat Adhakhir. He turned to me, and I was wearing a thin cloak dyed with safflower, and said: ‘What is this?’ And I realized that he disliked it. I came to my family when they were heating their oven and threw it (in the oven). Then I came to him the following day and he said: ‘O ‘Abdullah, what happened to the thin cloak?’ I told him (what I had done) and he said: ‘Why did you not give it to some of your family to wear, for there is nothing wrong with it for women.’”}}
\hadithdefcmd{ibnmajah}{3604}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنِ ابْنِ أَبِي لَيْلَى، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ مُحَمَّدِ بْنِ شُرَحْبِيلَ، عَنْ قَيْسِ بْنِ سَعْدٍ، قَالَ أَتَانَا النَّبِيُّ ـ صلى الله عليه وسلم ـ فَوَضَعْنَا لَهُ مَاءً يَتَبَرَّدُ بِهِ فَاغْتَسَلَ ثُمَّ أَتَيْتُهُ بِمِلْحَفَةٍ صَفْرَاءَ فَرَأَيْتُ أَثَرَ الْوَرْسِ عَلَى عُكَنِهِ ‏.‏\hadithno{3604}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Qais bin Sa’d said:“The Prophet (ﷺ) came to us and we gave him some water with which to cool down. He bathed, then I brought him a yellow blanket, and I saw the traces of Wars (the yellow dye) on the folds of his stomach.”}}
\hadithdefcmd{ibnmajah}{3605}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ كُلُوا وَاشْرَبُوا وَتَصَدَّقُوا وَالْبَسُوا مَا لَمْ يُخَالِطْهُ إِسْرَافٌ أَوْ مَخِيلَةٌ ‏"‏ ‏.‏\hadithno{3605}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Amr bin Shu’aib, from his father, that his grandfather said:“The Messenger of Allah (ﷺ) said: ‘Eat and drink, give charity and wear clothes, as long as that does not involve any extravagance or vanity.’”}}
\hadithdefcmd{ibnmajah}{3606}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبَادَةَ، وَمُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ الْوَاسِطِيَّانِ، قَالاَ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا شَرِيكٌ، عَنْ عُثْمَانَ بْنِ أَبِي زُرْعَةَ، عَنْ مُهَاجِرٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ لَبِسَ ثَوْبَ شُهْرَةٍ أَلْبَسَهُ اللَّهُ يَوْمَ الْقِيَامَةِ ثَوْبَ مَذَلَّةٍ ‏"‏ ‏.‏\hadithno{3606}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn ‘Umar said:“The Messenger of Allah (ﷺ) said: ‘Whoever wears a garment of pride and vanity, Allah will clothe him, on the Day of Resurrection, in a garment of humiliation.’”}}
\hadithdefcmd{ibnmajah}{3607}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ عُثْمَانَ بْنِ الْمُغِيرَةِ، عَنِ الْمُهَاجِرِ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ لَبِسَ ثَوْبَ شُهْرَةٍ فِي الدُّنْيَا أَلْبَسَهُ اللَّهُ ثَوْبَ مَذَلَّةٍ يَوْمَ الْقِيَامَةِ ثُمَّ أَلْهَبَ فِيهِ نَارًا ‏"‏ ‏.‏\hadithno{3607}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that ‘Abdullah bin ‘Umar said:“The Messenger of Allah (ﷺ) said: ‘Whoever wears a garment of pride and vanity in this world, Allah will clothe him in a garment of humiliation on the Day of Resurrection, then set it ablaze.’”}}
\hadithdefcmd{ibnmajah}{3608}{حَدَّثَنَا الْعَبَّاسُ بْنُ يَزِيدَ الْبَحْرَانِيُّ، حَدَّثَنَا وَكِيعُ بْنُ مُحْرِزٍ النَّاجِيُّ، حَدَّثَنَا عُثْمَانُ بْنُ جَهْمٍ، عَنْ زِرِّ بْنِ حُبَيْشٍ، عَنْ أَبِي ذَرٍّ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ لَبِسَ ثَوْبَ شُهْرَةٍ أَعْرَضَ اللَّهُ عَنْهُ حَتَّى يَضَعَهُ مَتَى وَضَعَهُ ‏"‏ ‏.‏\hadithno{3608}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Dharr that the Prophet (ﷺ) said:“Whoever wears a garment of pride and vanity, Allah will turn away from him until he takes it off.”}}
\hadithdefcmd{ibnmajah}{3609}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ وَعْلَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ أَيُّمَا إِهَابٍ دُبِغَ فَقَدْ طَهُرَ ‏"‏ ‏.‏\hadithno{3609}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn ‘Abbas said:“I heard the Messenger of Allah (ﷺ) say: ‘Any skin that has been tanned has been purified.’”}}
\hadithdefcmd{ibnmajah}{3610}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، عَنْ مَيْمُونَةَ، أَنَّ شَاةً، لِمَوْلاَةِ مَيْمُونَةَ مَرَّ بِهَا - يَعْنِي النَّبِيَّ ـ صلى الله عليه وسلم ـ - قَدْ أُعْطِيَتْهَا مِنَ الصَّدَقَةِ مَيْتَةً فَقَالَ ‏"‏ هَلاَّ أَخَذُوا إِهَابَهَا فَدَبَغُوهُ فَانْتَفَعُوا بِهِ ‏"‏ ‏.‏ فَقَالُوا يَا رَسُولَ اللَّهِ إِنَّهَا مَيْتَةٌ ‏.‏ قَالَ ‏"‏ إِنَّمَا حَرُمَ أَكْلُهَا ‏"‏ ‏.‏\hadithno{3610}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Maimunah that he (meaning the Prophet (ﷺ)) passed by a dead sheep belonging to the freed slave woman of Maimunah, that had been given to her in charity. He said:“Why don’t they take its skin and ten it, and make us of it?” They said: “O Messenger of Allah, it is dead meat.”* He said: “It is only unlawful to eat it.”}}
\hadithdefcmd{ibnmajah}{3611}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الرَّحِيمِ بْنُ سُلَيْمَانَ، عَنْ لَيْثٍ، عَنْ شَهْرِ بْنِ حَوْشَبٍ، عَنْ سَلْمَانَ، قَالَ كَانَ لِبَعْضِ أُمَّهَاتِ الْمُؤْمِنِينَ شَاةٌ فَمَاتَتْ فَمَرَّ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَلَيْهَا فَقَالَ ‏ "‏ مَا ضَرَّ أَهْلَ هَذِهِ لَوِ انْتَفَعُوا بِإِهَابِهَا ‏"‏ ‏.‏\hadithno{3611}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Salman said:“One of the Mothers of the Believers had a sheep that died. The Messenger of Allah (ﷺ) passed by it and said: ‘It would not have harmed its owners if they had made use of its hide.’”}}
\hadithdefcmd{ibnmajah}{3612}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنْ يَزِيدَ بْنِ قُسَيْطٍ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أُمِّهِ، عَنْ عَائِشَةَ، قَالَتْ أَمَرَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ يُسْتَمْتَعَ بِجُلُودِ الْمَيْتَةِ إِذَا دُبِغَتْ ‏.‏\hadithno{3612}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that ‘Aishah said:“The Messenger of Allah (ﷺ) commanded that use should be made of the skins of dead animals, if they were tanned.”}}
\hadithdefcmd{ibnmajah}{3613}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنِ الشَّيْبَانِيِّ، ح وَحَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا غُنْدَرٌ، عَنْ شُعْبَةَ، كُلُّهُمْ عَنِ الْحَكَمِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ عَبْدِ اللَّهِ بْنِ عُكَيْمٍ، قَالَ أَتَانَا كِتَابُ النَّبِيِّ ـ صلى الله عليه وسلم ـ ‏ "‏ أَنْ لاَ تَنْتَفِعُوا مِنَ الْمَيْتَةِ بِإِهَابٍ وَلاَ عَصَبٍ ‏"‏ ‏.‏\hadithno{3613}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that ‘Abdullah bin ‘Ukaym said:“There came to us a letter from the Prophet (ﷺ) (saying): ‘No not make use of the untanned skin and sinew of dead animals.’”}}
\hadithdefcmd{ibnmajah}{3614}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، عَنْ عَبْدِ اللَّهِ بْنِ الْعَبَّاسِ، قَالَ كَانَ لِنَعْلِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قِبَالاَنِ مَثْنِيٌّ شِرَاكُهُمَا ‏.‏\hadithno{3614}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Abdullah bin ‘Abbas said:“The sandals of the Prophet (ﷺ) had two thongs doubled around their straps.”}}
\hadithdefcmd{ibnmajah}{3615}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ هَمَّامٍ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ كَانَ لِنَعْلِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قِبَالاَنِ ‏.‏\hadithno{3615}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Anas said:“The sandals of the Prophet (ﷺ) had two thongs.”}}
\hadithdefcmd{ibnmajah}{3616}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا وَكِيعٌ، عَنْ شُعْبَةَ، عَنْ مُحَمَّدِ بْنِ زِيَادٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا انْتَعَلَ أَحَدُكُمْ فَلْيَبْدَأْ بِالْيُمْنَى وَإِذَا خَلَعَ فَلْيَبْدَأْ بِالْيُسْرَى ‏"‏ ‏.‏\hadithno{3616}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“When anyone of you puts on his sandals, let him start with the right, and when he takes them off, let him start with the left.”}}
\hadithdefcmd{ibnmajah}{3617}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنِ ابْنِ عَجْلاَنَ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ يَمْشِي أَحَدُكُمْ فِي نَعْلٍ وَاحِدٍ وَلاَ خُفٍّ وَاحِدٍ لِيَخْلَعْهُمَا جَمِيعًا أَوْ لِيَمْشِ فِيهِمَا جَمِيعًا ‏"‏ ‏.‏\hadithno{3617}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said; “None of you should walk in one sandal or in one leather sock. Let him take them both off or walk in both of them.”}}
\hadithdefcmd{ibnmajah}{3618}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ يَنْتَعِلَ الرَّجُلُ قَائِمًا ‏.‏\hadithno{3618}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:“The Messenger of Allah (ﷺ) forbade putting on sandals whilst standing.”}}
\hadithdefcmd{ibnmajah}{3619}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، قَالَ نَهَى النَّبِيُّ ـ صلى الله عليه وسلم ـ أَنْ يَنْتَعِلَ الرَّجُلُ قَائِمًا ‏.‏\hadithno{3619}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Umar said:“The Prophet (ﷺ) forbade putting on sandals whilst standing.”}}
\hadithdefcmd{ibnmajah}{3620}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا دَلْهَمُ بْنُ صَالِحٍ الْكِنْدِيُّ، عَنْ حُجَيْرِ بْنِ عَبْدِ اللَّهِ الْكِنْدِيِّ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، أَنَّ النَّجَاشِيَّ، أَهْدَى لِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ خُفَّيْنِ سَاذَجَيْنِ أَسْوَدَيْنِ فَلَبِسَهُمَا ‏.‏\hadithno{3620}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn Buraidah, from his father, that an-Najashi sent a pair of pure black Khuff as a gift to the Prophet (ﷺ) of, which he wore}}
\hadithdefcmd{ibnmajah}{3621}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، سَمِعَ أَبَا سَلَمَةَ، وَسُلَيْمَانَ بْنَ يَسَارٍ، يُخْبِرَانِ عَنْ أَبِي هُرَيْرَةَ، يَبْلُغُ بِهِ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِنَّ الْيَهُودَ وَالنَّصَارَى لاَ يَصْبُغُونَ فَخَالِفُوهُمْ ‏"‏ ‏.‏\hadithno{3621}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Hurairah attributed to the Prophet (ﷺ):“The Jews and the Christians do not dye (their hair), so differ from them.”}}
\hadithdefcmd{ibnmajah}{3622}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنِ الأَجْلَحِ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ أَبِي الأَسْوَدِ الدِّيلِيِّ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ أَحْسَنَ مَا غَيَّرْتُمْ بِهِ الشَّيْبَ الْحِنَّاءُ وَالْكَتَمُ ‏"‏ ‏.‏\hadithno{3622}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Dharr that the Messenger of Allah (ﷺ) said:“The best things with which you change gray hair are henna and Katam.”}}
\hadithdefcmd{ibnmajah}{3623}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا يُونُسُ بْنُ مُحَمَّدٍ، حَدَّثَنَا سَلاَّمُ بْنُ أَبِي مُطِيعٍ، عَنْ عُثْمَانَ بْنِ مَوْهَبٍ، قَالَ دَخَلْتُ عَلَى أُمِّ سَلَمَةَ ‏.‏ قَالَ فَأَخْرَجَتْ إِلَىَّ شَعَرًا مِنْ شَعَرِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ مَخْضُوبًا بِالْحِنَّاءِ وَالْكَتَمِ ‏.‏\hadithno{3623}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that ‘Uthman bin Mawhab said:“I entered upon Umm Salamah and she brought out for me a hair of the Messenger of Allah (ﷺ), which was dyed with henna and Katam.”}}
\hadithdefcmd{ibnmajah}{3624}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ لَيْثٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ جِيءَ بِأَبِي قُحَافَةَ يَوْمَ الْفَتْحِ إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ وَكَأَنَّ رَأْسَهُ ثَغَامَةٌ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ اذْهَبُوا بِهِ إِلَى بَعْضِ نِسَائِهِ فَلْتُغَيِّرْهُ وَجَنِّبُوهُ السَّوَادَ ‏"‏ ‏.‏\hadithno{3624}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Jabir that he said:“Abu Quhaifah was brought to the Prophet (ﷺ) on the Day of the Conquest (of Makkah), and his head was all white. The Messenger of Allah (ﷺ) said: ‘Take him to some of his womenfolk and let them change this, but avoid black.’”}}
\hadithdefcmd{ibnmajah}{3625}{حَدَّثَنَا أَبُو هُرَيْرَةَ الصَّيْرَفِيُّ، مُحَمَّدُ بْنُ فِرَاسٍ حَدَّثَنَا عُمَرُ بْنُ الْخَطَّابِ بْنِ زَكَرِيَّا الرَّاسِبِيُّ، حَدَّثَنَا دَفَّاعُ بْنُ دَغْفَلٍ السَّدُوسِيُّ، عَنْ عَبْدِ الْحَمِيدِ بْنِ صَيْفِيٍّ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، صُهَيْبِ الْخَيْرِ قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ أَحْسَنَ مَا اخْتَضَبْتُمْ بِهِ لَهَذَا السَّوَادُ أَرْغَبُ لِنِسَائِكُمْ فِيكُمْ وَأَهْيَبُ لَكُمْ فِي صُدُورِ عَدُوِّكُمْ ‏"‏ ‏.‏\hadithno{3625}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Suhaib Al-Khair said:“The Messenger of Allah (ﷺ) said: ‘The best thing with which you can dye your hair is this black (dye). It makes your women desire you and creates fear in the hearts of your enemies.’”}}
\hadithdefcmd{ibnmajah}{3626}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، أَنَّ عُبَيْدَ بْنَ جُرَيْجٍ، سَأَلَ ابْنَ عُمَرَ قَالَ رَأَيْتُكَ تُصَفِّرُ لِحْيَتَكَ بِالْوَرْسِ فَقَالَ ابْنُ عُمَرَ أَمَّا تَصْفِيرِي لِحْيَتِي فَإِنِّي رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يُصَفِّرُ لِحْيَتَهُ ‏.‏\hadithno{3626}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Sa’eed bin Abu Sa’eed that ‘Ubaid bin Juraij asked Ibn ‘Umar:“I see that you dye your beard yellow with Wars.” Ibn ‘Umar said: “As for my dyeing of my beard yellow with Wars, I saw the Messenger of Allah (ﷺ) dyeing his beard yellow.”}}
\hadithdefcmd{ibnmajah}{3627}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، حَدَّثَنَا مُحَمَّدُ بْنُ طَلْحَةَ، عَنْ حُمَيْدِ بْنِ وَهْبٍ، عَنِ ابْنِ طَاوُسٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ مَرَّ النَّبِيُّ ـ صلى الله عليه وسلم ـ عَلَى رَجُلٍ قَدْ خَضَبَ بِالْحِنَّاءِ فَقَالَ ‏"‏ مَا أَحْسَنَ هَذَا ‏"‏ ‏.‏ ثُمَّ مَرَّ بِآخَرَ قَدْ خَضَبَ بِالْحِنَّاءِ وَالْكَتَمِ فَقَالَ ‏"‏ هَذَا أَحْسَنُ مِنْ هَذَا ‏"‏ ‏.‏ ثُمَّ مَرَّ بِآخَرَ قَدْ خَضَبَ بِالصُّفْرَةِ فَقَالَ ‏"‏ هَذَا أَحْسَنُ مِنْ هَذَا كُلِّهِ ‏"‏ ‏.‏ قَالَ وَكَانَ طَاوُسٌ يُصَفِّرُ ‏.‏\hadithno{3627}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Abbas said:“The Prophet (ﷺ) passed by a man who had dyed his hair with henna and said: ‘How handsome this is!’ Then he passed by another who had dyed his hair with henna and Katam, and said: ‘This one is more handsome than that one.’ Then he passed by another who had dyed his hair yellow and said: ‘This one is more handsome than all of them.’”}}
\hadithdefcmd{ibnmajah}{3628}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا زُهَيْرٌ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي جُحَيْفَةَ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ هَذِهِ مِنْهُ بَيْضَاءُ ‏.‏ يَعْنِي عَنْفَقَتَهُ ‏.‏\hadithno{3628}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Juhaifah said:“I saw the Messenger of Allah (ﷺ), and this part of his hair was white” – meaning the tuft of hair between the lower lip and the chin}}
\hadithdefcmd{ibnmajah}{3629}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، وَابْنُ أَبِي عَدِيٍّ، عَنْ حُمَيْدٍ، قَالَ سُئِلَ أَنَسُ بْنُ مَالِكٍ أَخَضَبَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ إِنَّهُ لَمْ يَرَ مِنَ الشَّيْبِ إِلاَّ نَحْوَ سَبْعَةَ عَشَرَ أَوْ عِشْرِينَ شَعَرَةً فِي مُقَدَّمِ لِحْيَتِهِ ‏.‏\hadithno{3629}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Humaid said:“Anas bin Malik was asked: ‘Did the Messenger of Allah (ﷺ) dye his hair?’ He said: ‘He did not have any white hair apart from approximately seventeen or twenty hairs at the front of his beard.’”}}
\hadithdefcmd{ibnmajah}{3630}{حَدَّثَنَا مُحَمَّدُ بْنُ عُمَرَ بْنِ الْوَلِيدِ الْكِنْدِيُّ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، عَنْ شَرِيكٍ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ شَيْبُ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ نَحْوَ عِشْرِينَ شَعَرَةً ‏.‏\hadithno{3630}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn ‘Umar said:“The white hair of the Prophet (ﷺ) numbered approximately twenty.”}}
\hadithdefcmd{ibnmajah}{3631}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ مُجَاهِدٍ، قَالَ قَالَتْ أُمُّ هَانِئٍ دَخَلَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ مَكَّةَ وَلَهُ أَرْبَعُ غَدَائِرَ ‏.‏ تَعْنِي ضَفَائِرَ ‏.‏\hadithno{3631}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Mujahid said:“Umm Hani said: ‘When the Messenger of Allah (ﷺ) entered Makkah he had four braids.’”}}
\hadithdefcmd{ibnmajah}{3632}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، عَنْ إِبْرَاهِيمَ بْنِ سَعْدٍ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ أَهْلُ الْكِتَابِ يَسْدُلُونَ أَشْعَارَهُمْ وَكَانَ الْمُشْرِكُونَ يَفْرِقُونَ وَكَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يُحِبُّ مُوَافَقَةَ أَهْلِ الْكِتَابِ ‏.‏ قَالَ فَسَدَلَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ نَاصِيَتَهُ ثُمَّ فَرَقَ بَعْدُ ‏.‏\hadithno{3632}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn ‘Abbas said:“The People of the Book used to let their hair hang down, and the idolaters used to part their hair. The Messenger of Allah (ﷺ) liked to be more like the People of the Book. So the Messenger of Allah (ﷺ) let his forelock hang down, then after that he parted it.”}}
\hadithdefcmd{ibnmajah}{3633}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ بْنِ سَعْدٍ، عَنِ ابْنِ إِسْحَاقَ، عَنْ يَحْيَى بْنِ عَبَّادٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أَفْرِقُ خَلْفَ يَافُوخِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ثُمَّ أَسْدِلُ نَاصِيَتَهُ ‏.‏\hadithno{3633}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that ‘Aishah said:“I used to part the hair of the Messenger of Allah (ﷺ) behind his crown, and let his forelock hang down.”}}
\hadithdefcmd{ibnmajah}{3634}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا جَرِيرُ بْنُ حَازِمٍ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ كَانَ شَعَرُ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ شَعَرًا رَجِلاً بَيْنَ أُذُنَيْهِ وَمَنْكِبَيْهِ\hadithno{3634}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Anas said:“The hair of the Messenger of Allah (ﷺ) was wavy, and (hung down) between his ears and his shoulders.”}}
\hadithdefcmd{ibnmajah}{3635}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي الزِّنَادِ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ لِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ شَعَرٌ دُونَ الْجُمَّةِ وَفَوْقَ الْوَفْرَةِ.‏\hadithno{3635}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that ‘Aishah said:“The Messenger of Allah (ﷺ) had hair that came between his earlobes and his shoulders.”}}
\hadithdefcmd{ibnmajah}{3636}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُعَاوِيَةُ بْنُ هِشَامٍ، وَسُفْيَانُ بْنُ عُقْبَةَ، عَنْ سُفْيَانَ، عَنْ عَاصِمِ بْنِ كُلَيْبٍ، عَنْ أَبِيهِ، عَنْ وَائِلِ بْنِ حُجْرٍ، قَالَ رَآنِيَ النَّبِيُّ ـ صلى الله عليه وسلم ـ وَلِي شَعَرٌ طَوِيلٌ فَقَالَ ‏"‏ ذُبَابٌ ذُبَابٌ ‏"‏ ‏.‏ فَانْطَلَقْتُ فَأَخَذْتُهُ فَرَآنِيَ النَّبِيُّ ـ صلى الله عليه وسلم ـ فَقَالَ ‏"‏ إِنِّي لَمْ أَعْنِكَ وَهَذَا أَحْسَنُ ‏"‏ ‏.‏\hadithno{3636}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Wa’il bin Hujr said:“The Prophet (ﷺ) saw me when I had long hair. He said: ‘Bad news, bad news!’ So I went away and cut it short. Then the Prophet (ﷺ) saw me and said: ‘I did not mean you, but this is better.’”}}
\hadithdefcmd{ibnmajah}{3637}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ عُمَرَ بْنِ نَافِعٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ نَهَى رَسُولُ اللَّهُ ـ صلى الله عليه وسلم ـ عَنِ الْقَزَعِ ‏.‏ قَالَ وَمَا الْقَزَعُ قَالَ أَنْ يُحْلَقَ مِنْ رَأْسِ الصَّبِيِّ مَكَانٌ وَيُتْرَكَ مَكَانٌ ‏.‏\hadithno{3637}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Nafi’ that Ibn ‘Umar said:“The Messenger of Allah (ﷺ) forbade Qaza’.” He (Nafi’) said: “What is Qaza’?” He said: “It means shaving part of a child’s head and leaving another part.”}}
\hadithdefcmd{ibnmajah}{3638}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَبَابَةُ، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنِ الْقَزَعِ ‏.‏\hadithno{3638}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Ibn ‘Umar said:“The Messenger of Allah (ﷺ) forbade Qaza’.”}}
\hadithdefcmd{ibnmajah}{3639}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَيُّوبَ بْنِ مُوسَى، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ اتَّخَذَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ خَاتَمًا مِنْ وَرِقٍ ثُمَّ نَقَشَ فِيهِ مُحَمَّدٌ رَسُولُ اللَّهِ فَقَالَ ‏ "‏ لاَ يَنْقُشْ أَحَدٌ عَلَى نَقْشِ خَاتَمِي هَذَا ‏"‏ ‏.‏\hadithno{3639}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn ‘Umar said:“The Messenger of Allah (ﷺ) wore a ring of silver, then he had engraved on it (the words) ‘Muhammad Rasul Allah’ (Muhammad the Messenger of Allah). And he said: ‘No one should have his ring engraved like this ring of mine.’”}}
\hadithdefcmd{ibnmajah}{3640}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ اصْطَنَعَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ خَاتَمًا فَقَالَ ‏ "‏ إِنَّا قَدِ اصْطَنَعْنَا خَاتَمًا وَنَقَشْنَا فِيهِ نَقْشًا فَلاَ يَنْقُشَنَّ عَلَيْهِ أَحَدٌ ‏"‏ ‏.‏\hadithno{3640}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Anas bin Malik said:“The Messenger of Allah (ﷺ) had a ring made for him, and he said: ‘I have had a ring made for me and had it engraved, and no one should make a ring with similar engraving.’”}}
\hadithdefcmd{ibnmajah}{3641}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، حَدَّثَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ اتَّخَذَ خَاتَمًا مِنْ فِضَّةٍ لَهُ فَصٌّ حَبَشِيٌّ وَنَقْشُهُ مُحَمَّدٌ رَسُولُ اللَّهِ ‏.‏\hadithno{3641}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah (ﷺ) wore a ring of silver, in which was an Ethiopian gemstone and the inscription:‘Muhammad Rasul Allah’ (Muhammad the Messenger of Allah).”}}
\hadithdefcmd{ibnmajah}{3642}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعِ بْنِ جُبَيْرٍ، مَوْلَى عَلِيٍّ عَنْ عَلِيٍّ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنِ التَّخَتُّمِ بِالذَّهَبِ ‏.‏\hadithno{3642}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that ‘Ali said:“The Messenger of Allah (ﷺ) forbade wearing gold rings.”}}
\hadithdefcmd{ibnmajah}{3643}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ يَزِيدَ بْنِ أَبِي زِيَادٍ، عَنِ الْحَسَنِ بْنِ سُهَيْلٍ، عَنِ ابْنِ عُمَرَ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنْ خَاتَمِ الذَّهَبِ ‏.‏\hadithno{3643}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn ‘Umar said:“The Messenger of Allah (ﷺ) forbade gold rings.”}}
\hadithdefcmd{ibnmajah}{3644}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ يَحْيَى بْنِ عَبَّادِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ، قَالَتْ أَهْدَى النَّجَاشِيُّ إِلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ حَلْقَةً فِيهَا خَاتَمُ ذَهَبٍ فِيهِ فَصٌّ حَبَشِيٌّ فَأَخَذَهُ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ بِعُودٍ وَإِنَّهُ لَمُعْرِضٌ عَنْهُ أَوْ بِبَعْضِ أَصَابِعِهِ ثُمَّ دَعَا ابْنَةَ ابْنَتِهِ أُمَامَةَ بِنْتَ أَبِي الْعَاصِ فَقَالَ ‏ "‏ تَحَلَّىْ بِهَذَا يَا بُنَيَّةُ ‏"‏ ‏.‏\hadithno{3644}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that ‘Aishah the Mother of the Believers said:“Najashi sent some jewelry as a gift to the Messenger of Allah (ﷺ). Among that was a gold ring with an Ethiopian gemstone. The Messenger of Allah (ﷺ) picked it up with a stick – as if he found it distasteful – or with one of his fingers, then he called for his daughter, Umamah bint Abul-‘As, and said: ‘Wear this, O my daughter.’”}}
\hadithdefcmd{ibnmajah}{3645}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَيُّوبَ بْنِ مُوسَى، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ يَجْعَلُ فَصَّ خَاتَمِهِ مِمَّا يَلِي كَفَّهُ ‏.‏\hadithno{3645}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn ‘Umar that the Prophet (ﷺ) used to wear (his ring) with the stone nearest his palm}}
\hadithdefcmd{ibnmajah}{3646}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي أُوَيْسٍ، حَدَّثَنِي سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ يُونُسَ بْنِ يَزِيدَ الأَيْلِيِّ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ لَبِسَ خَاتَمَ فِضَّةٍ فِيهِ فَصٌّ حَبَشِيٌّ كَانَ يَجْعَلُ فَصَّهُ فِي بَطْنِ كَفِّهِ ‏.‏\hadithno{3646}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah (ﷺ) wore a silver ring with an Ethiopian gemstone, and he used to ear the stone in towards his palm}}
\hadithdefcmd{ibnmajah}{3647}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ إِبْرَاهِيمَ بْنِ الْفَضْلِ، عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلٍ، عَنْ عَبْدِ اللَّهِ بْنِ جَعْفَرٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ يَتَخَتَّمُ فِي يَمِينِهِ ‏.‏\hadithno{3647}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from ‘Abdullah bin Ja’far that the Prophet (ﷺ) used to wear a ring on his right hand}}
\hadithdefcmd{ibnmajah}{3648}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ عَاصِمٍ، عَنْ أَبِي بُرْدَةَ، عَنْ عَلِيٍّ، قَالَ نَهَانِي رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ أَتَخَتَّمَ فِي هَذِهِ وَفِي هَذِهِ يَعْنِي الْخِنْصَرَ وَالإِبْهَامَ ‏.‏\hadithno{3648}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that ‘Ali said:“The Messenger of Allah (ﷺ) forbade me to wear a ring on this and on this,” meaning the little finger and the thumb}}
\hadithdefcmd{ibnmajah}{3649}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، عَنْ أَبِي طَلْحَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ تَدْخُلُ الْمَلاَئِكَةُ بَيْتًا فِيهِ كَلْبٌ وَلاَ صُورَةٌ ‏"‏ ‏.‏\hadithno{3649}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Talhah that the Prophet (ﷺ) said:“The angels do not enter a house in which there is a dog or an image.”}}
\hadithdefcmd{ibnmajah}{3650}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا غُنْدَرٌ، عَنْ شُعْبَةَ، عَنْ عَلِيِّ بْنِ مُدْرِكٍ، عَنْ أَبِي زُرْعَةَ، عَنْ عَبْدِ اللَّهِ بْنِ نُجَىٍّ، عَنْ أَبِيهِ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِنَّ الْمَلاَئِكَةَ لاَ تَدْخُلُ بَيْتًا فِيهِ كَلْبٌ وَلاَ صُورَةٌ ‏"‏ ‏.‏\hadithno{3650}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from ‘Ali bin Abu Talib that the Prophet (ﷺ) said:“The angels do not enter a house in which there is a dog or an image.”}}
\hadithdefcmd{ibnmajah}{3651}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، قَالَتْ وَاعَدَ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ جِبْرِيلُ عَلَيْهِ السَّلاَمُ فِي سَاعَةٍ يَأْتِيهِ فِيهَا فَرَاثَ عَلَيْهِ فَخَرَجَ النَّبِيُّ ـ صلى الله عليه وسلم ـ فَإِذَا هُوَ بِجِبْرِيلَ قَائِمٌ عَلَى الْبَابِ فَقَالَ ‏ "‏ مَا مَنَعَكَ أَنْ تَدْخُلَ ‏"‏ ‏.‏ قَالَ إِنَّ فِي الْبَيْتِ كَلْبًا وَإِنَّا لاَ نَدْخُلُ بَيْتًا فِيهِ كَلْبٌ وَلاَ صُورَةٌ ‏.‏\hadithno{3651}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that ‘Aishah said:“Jibril (as) promised the Messenger of Allah (ﷺ) that he would come to him at a certain hour, but he was late. The Prophet (ﷺ) went out and there was Jibril standing at the door. He said: ‘What kept you from entering?’ He said: ‘There is a dog in the house, and we do not enter a house in which there is a dog or an image.’”}}
\hadithdefcmd{ibnmajah}{3652}{حَدَّثَنَا الْعَبَّاسُ بْنُ عُثْمَانَ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ، حَدَّثَنَا عُفَيْرُ بْنُ مَعْدَانَ، حَدَّثَنَا سُلَيْمُ بْنُ عَامِرٍ، عَنْ أَبِي أُمَامَةَ، أَنَّ امْرَأَةً، أَتَتِ النَّبِيَّ ـ صلى الله عليه وسلم ـ فَأَخْبَرَتْهُ أَنَّ زَوْجَهَا فِي بَعْضِ الْمَغَازِي فَاسْتَأْذَنَتْهُ أَنْ تُصَوِّرَ فِي بَيْتِهَا نَخْلَةً فَمَنَعَهَا أَوْ نَهَاهَا ‏.‏\hadithno{3652}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Umamah that a woman came to the Prophet (ﷺ) and told him that her husband was away on some military campaign. She asked him for permission to make an image of a palm tree in her house, and he did not let her, or he forbade her}}
\hadithdefcmd{ibnmajah}{3653}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ سَتَرْتُ سَهْوَةً لِي - تَعْنِي الدَّاخِلَ - بِسِتْرٍ فِيهِ تَصَاوِيرُ فَلَمَّا قَدِمَ النَّبِيُّ ـ صلى الله عليه وسلم ـ هَتَكَهُ فَجَعَلْتُ مِنْهُ مَنْبُوذَتَيْنِ فَرَأَيْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ مُتَّكِئًا عَلَى إِحْدَاهُمَا ‏.‏\hadithno{3653}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Sahih - Isnaad Hasan Bukhari And Muslim}\hadithtrans{It was narrated that ‘Aishah said:“I covered a small room closet of mine, meaning, from the inside, with a curtain on which there were images. When the Prophet (ﷺ) came, he tore it down, so I made two pillows from it, and I saw the Prophet (ﷺ) reclining on one of them.”}}
\hadithdefcmd{ibnmajah}{3654}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنْ هُبَيْرَةَ، عَنْ عَلِيٍّ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنْ خَاتَمِ الذَّهَبِ وَعَنِ الْمِيثَرَةِ يَعْنِي الْحَمْرَاءَ ‏.‏\hadithno{3654}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that ‘Ali said:“The Messenger of Allah (ﷺ) forbade rings of gold and Al-Mitharah,”* meaning the red ones}}
\hadithdefcmd{ibnmajah}{3655}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، حَدَّثَنِي عَيَّاشُ بْنُ عَبَّاسٍ الْحِمْيَرِيُّ، عَنْ أَبِي حُصَيْنٍ الْحَجْرِيِّ الْهَيْثَمِ، عَنْ عَامِرٍ الْحَجْرِيِّ، قَالَ سَمِعْتُ أَبَا رَيْحَانَةَ، صَاحِبَ النَّبِيِّ ـ صلى الله عليه وسلم ـ يَقُولُ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ يَنْهَى عَنْ رُكُوبِ النُّمُورِ ‏.‏\hadithno{3655}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Amir Al-Hajri said:“I heard Abu Raihanah, the Companion of the Prophet (ﷺ) say: ‘The Prophet (ﷺ) used to forbid riding on leopard skins.’”}}
\hadithdefcmd{ibnmajah}{3656}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ أَبِي الْمُعْتَمِرِ، عَنِ ابْنِ سِيرِينَ، عَنْ مُعَاوِيَةَ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَنْهَى عَنْ رُكُوبِ النُّمُورِ ‏.‏\hadithno{3656}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Mu’awiyah said:“The Messenger of Allah (ﷺ) used to forbid riding on leopard skins.”}}
